import os

from datetime import datetime
from requests_forecast import Forecast


def main():
    forecast = Forecast(os.environ.get('FORECAST_IO_API'),
                        latitude=38.9717,
                        longitude=-95.235,
                        time=datetime.now())  # (year=2013, month=12, day=29, hour=12))
    print '+' * 20

    currently = forecast.get_currently()
    print 'current.temperature: {}'.format(currently.temperature)
    print 'current.cloudCover: {}'.format(currently.cloudCover)
    print 'current.humidity: {}'.format(currently.humidity)
    print 'current.icon: {}'.format(currently.icon)
    #print 'current.precipIntensity: {}'.format(currently.get('precipIntensity'))
    print 'current.precipIntensity: {}'.format(currently.precipIntensity)
    print 'current.pressure: {}'.format(currently.pressure)
    print 'current.summary: {}'.format(currently.summary)
    print 'current.time: {}'.format(currently.time)
    print 'current.visibility: {}'.format(currently.visibility)
    print 'current.windBearing: {}'.format(currently.windBearing)
    print 'current.windSpeed: {}'.format(currently.windSpeed)
    #print 'current: {}'.format(currently)
    print '-' * 20

    #{u'temperature': 47.68, u'humidity': 0.58, u'cloudCover': 0.63, u'summary': u'Mostly Cloudy',
    #u'pressure': 986.74, u'windSpeed': 11.12, u'visibility': 9.3, u'time': 1364422970, u'windBearing': 102, u'precipIntensity': 0, u'icon': u'partly-cloudy-day'}

    #print 'daily: {}'.format(len(daily['data']))
    #print 'daily: {}'.format(daily)
    daily = forecast.get_daily()
    print 'daily: {}'.format(len(daily))
    #print 'daily: {}'.format(daily.data)
    for day in daily.data:
        print '- {} | {} | {} | {}'.format(day.sunriseTime, day.sunsetTime, day.temperatureMin, day.temperatureMax)
    print '-' * 20
    print 'daily: {}'.format(daily['data'][0]['temperatureMin'])
    print 'daily: {}'.format(daily['data'][0]['temperatureMax'])
    print 'daily: {}'.format(daily)

    hourly = forecast.get_hourly()
    print 'hourly: {}'.format(len(hourly['data']))
    #print 'minutely: {}'.format(len(forecast.minutely['data']))

    alerts = forecast.get_alerts()
    print alerts


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
import datetime
import pytz
import requests
import time as time_mod


__title__ = 'requests-forecast'
__version__ = '0.4.1'
__author__ = 'Jeff Triplett'
__license__ = 'BSD'
__copyright__ = 'Copyright 2013 Jeff Triplett'


FORECAST_TEMPLATE = 'https://api.forecast.io/forecast/{apikey}/{latitude},{longitude}{time}'


class DataPoint(dict):

    def __init__(self, data=None, timezone=None):
        self.timezone = timezone
        super(DataPoint, self).__init__(data)

    def __getattr__(self, attr):
        try:
            if attr in ['expires', 'time'] or attr.endswith('Time'):
                self[attr] = datetime.datetime.fromtimestamp(int(self[attr]))  # .replace(tzinfo=self.timezone)
            return self[attr]
        except KeyError:
            raise AttributeError(attr)


class DataBlock(DataPoint):

    def __init__(self, data=None, timezone=None):
        self.timezone = timezone
        super(DataBlock, self).__init__(data or {})
        self.data = []

        if data is not None and 'data' in data:
            for datapoint in data['data']:
                self.data.append(DataBlock(datapoint, timezone=timezone))


class Forecast(object):
    json = None
    timezone = None

    def __init__(self, apikey, latitude=None, longitude=None, time=None, parse_timestamps=True):
        self.apikey = apikey
        self.parse_timestamps = parse_timestamps
        self.latitude = latitude
        self.longitude = longitude
        self.time = time

        self.get(latitude, longitude, time)

        if 'timezone' in self.json:
            self.timezone = pytz.timezone(self.json['timezone'])

    def get(self, latitude=None, longitude=None, time=None):
        if time:
            time = int(time_mod.mktime(time.timetuple()))

        url = FORECAST_TEMPLATE.format(
            apikey=self.apikey,
            latitude=latitude or self.latitude,
            longitude=longitude or self.longitude,
            time=',{}'.format(time) if self.time else ''
        )

        request = requests.get(url, headers={'Accept-Encoding': 'gzip'})
        self.json = request.json()

    def get_alerts(self):
        if 'alerts' in self.json:
            return DataBlock(self.json.alerts, self.timezone)
        return DataBlock()

    def get_currently(self):
        if 'currently' in self.json:
            return DataBlock(self.json['currently'], self.timezone)
        return DataBlock()

    def get_daily(self):
        if 'daily' in self.json:
            return DataBlock(self.json['daily'], self.timezone)
        return DataBlock()

    def get_hourly(self):
        if 'hourly' in self.json:
            return DataBlock(self.json['hourly'], self.timezone)
        return DataBlock()

    def get_minutely(self):
        if 'minutely' in self.json:
            return DataBlock(self.json['minutely'], self.timezone)
        return DataBlock()
